[−][src]Crate send
Send
Project
- Repository: https://bitbucket.org/haibison/send-rs
- License: Free Public License 1.0.0
- This project follows Semantic Versioning 2.0.0
This program lets the user type in input, then sends it to one other program.
Other program can be either:
-
Piped via stdout. In this case, all input data will be sent untouched.
-
Or specified after a double-hyphen phrase (
--). The phrase{}will be replaced with input data. Since this method sends input data via command line, it will be filtered. The program will exit withERROR_EXIT_CODEif it detects some illegal characters, such as:#0, tab, line break...
If both methods are used at once, the program will exit with ERROR_EXIT_CODE.
Modules
| version_info |
|
Constants
| CODE_NAME | Crate code name |
| ERROR_EXIT_CODE | Error exit code |
| NAME | Crate name |
| RELEASE_DATE | Crate release date (year/month/day) |
| TAG | Tag, which can be used for logging... |
| UUID | Unique universally identifier of this crate |
| VERSION | Crate version |